Updated accumulator documentation and refactored names to remove the event heritage.

Change-Id: I2238ab1215281702e670a406fb901ba8a4ef85ce
diff --git a/utils/misc/src/main/java/org/onlab/util/Accumulator.java b/utils/misc/src/main/java/org/onlab/util/Accumulator.java
index 897bddf..568e38c 100644
--- a/utils/misc/src/main/java/org/onlab/util/Accumulator.java
+++ b/utils/misc/src/main/java/org/onlab/util/Accumulator.java
@@ -18,25 +18,28 @@
 import java.util.List;
 
 /**
  * Abstraction of an accumulator capable of collecting events and at some
  * point in time triggers processing of all previously accumulated events.
  */
 public interface Accumulator<T> {
 
     /**
      * Adds an event to the current batch. This operation may, or may not
      * trigger processing of the current batch of events.
      *
      * @param event event to be added to the current batch
      */
-    void add(T event);
+    void add(T item);
 
     /**
      * Processes the specified list of accumulated events.
      *
      * @param events list of accumulated events
      */
-    void processEvents(List<T> events);
+    void processItems(List<T> items);
 
     //TODO consider a blocking version that required consumer participation
+
 }
@@ -18,25 +18,28 @@
 
 /**
- * Abstraction of an accumulator capable of collecting events and at some
- * point in time triggers processing of all previously accumulated events.
+ * Abstraction of an accumulator capable of collecting items and at some
+ * point in time triggers processing of all previously accumulated items.
+ *
+ * @param <T> item type
  */
 public interface Accumulator<T> {
@@ -18,25 +18,28 @@
 
     /**
-     * Adds an event to the current batch. This operation may, or may not
-     * trigger processing of the current batch of events.
+     * Adds an item to the current batch. This operation may, or may not
+     * trigger processing of the current batch of items.
      *
@@ -18,25 +18,28 @@
      *
-     * @param event event to be added to the current batch
+     * @param item item to be added to the current batch
      */
@@ -18,25 +18,28 @@
 
     /**
-     * Processes the specified list of accumulated events.
+     * Processes the specified list of accumulated items.
      *
@@ -18,25 +18,28 @@
      *
-     * @param events list of accumulated events
+     * @param items list of accumulated items
      */